from django.contrib.gis.db import models


class Flyover(models.Model):
  point = models.PointField()
  name = models.CharField(max_length=255)
  txt = models.TextField(blank=True, null=True)
  objects = models.GeoManager()

  def __unicode__(self):
    return self.name

  def geojson_as_dict(self):
    return {
      'type': 'Feature',
      'geometry': {'type': 'Point', 'coordinates': [self.point.x, self.point.y]},
      'properties': {'id': self.id}
      }

  def get_media(self):
    d = {
      'images': []
    }
    images = Image.objects.filter(flyover=self)
    for i in images:
      d['images'].append(i.get_dict())
    return d

class Image(models.Model):
  url = models.URLField("FlickR URL")
  caption = models.CharField(max_length=255, blank=True, null=True)
  category = models.ForeignKey("ImageCategory")
  flyover = models.ForeignKey(Flyover)

  def __unicode__(self):
    return self.url + " - " + self.caption + " - " + self.category.name

  def get_dict(self):
    return {
      'url': self.url,
      'caption': self.caption
    }

class ImageCategory(models.Model):
  name = models.CharField(max_length=255)
  description = models.TextField(blank=True, null=True)

  def __unicode__(self):
    return self.name

class Video(models.Model):
  url = models.URLField("Youtube URL")
  caption = models.CharField(max_length=255, blank=True, null=True)
  category = models.ForeignKey("VideoCategory")
  flyover = models.ForeignKey(Flyover)

  def __unicode__(self):
    return self.url + " - " + self.caption + " - " + self.category.name

class VideoCategory(models.Model):
  name = models.CharField(max_length=255)
  description = models.TextField(blank=True, null=True)

  def __unicode__(self):
    return self.name

class Audio(models.Model):
  fil = models.FileField(upload_to='audio/')
  caption = models.CharField(max_length=255, blank=True, null=True)
  category = models.ForeignKey("AudioCategory")
  flyover = models.ForeignKey(Flyover)

  def __unicode__(self):
    return self.url + " - " + self.caption + " - " + self.category.name

class AudioCategory(models.Model):
  name = models.CharField(max_length=255)
  description = models.TextField(blank=True, null=True)

  def __unicode__(self):
    return self.name

class Text(models.Model):
#  url = models.URLField("FlickR URL")
  text = models.TextField(max_length=255)
  category = models.ForeignKey("TextCategory")
  flyover = models.ForeignKey(Flyover)

  def __unicode__(self):
    return self.text + " - " + self.category.name

class TextCategory(models.Model):
  name = models.CharField(max_length=255)
  description = models.TextField(blank=True, null=True)

  def __unicode__(self):
    return self.name

# Create your models here.
